LocalUserGroups - Python Wiki

Search:

- LocalUserGroups

- LocalUserGroups

Users of the Python programming language meet periodically in so-called Python User Groups 1. Intermediate and advanced users share how they use the language and learn new tricks; they also welcome beginners and help them step in. It is a great place to ask for help and socialize with other people with a similar interest. Meetings are usually once every month, they are very informal and open to everyone.

There about 401 Python user groups worldwide in almost 191 cities, 37 countries and over 127,100 members. Check in these two places to find if there is already a group in your area:

- The list below which is sorted by geographical region, country, and state in some cases.

- A world map of Python Meetups in meetup.com. Enter your country and city to list the local group if any.

If there is not a Python user group in your area, please check StartingYourUsersGroup if you are interested in organizing one.

Contents

1. Asia
   1. Bangladesh
   2. Cambodia(សីល >>> សមាធិ >>> បញ្ញា)
   3. China
   4. Hong Kong
   5. India
   6. Indonesia
   7. Iran
   8. Japan
   9. Pakistan
   10. Korea
   11. Malaysia
   12. Nepal
   13. Singapore
   14. Sri Lanka
   15. Taiwan
   16. Philippines
   17. Thailand/ประเทศไทย
2. Oceania
   1. Australia
   2. New Zealand
3. Canada
4. Caribbean
5. Europe
   1. Austria
   2. Belgium
   3. Croatia
   4. Czech and Slovak
   5. Denmark
   6. Finland
   7. France
   8. Georgia
   9. Germany
      1. General Community Resources
      2. User Groups
   10. Greece
   11. Hungary
   12. Iceland
   13. Ireland
   14. Italy
   15. Kosovo
   16. Latvia
   17. Malta
   18. Moldova
   19. Montenegro
   20. The Netherlands
   21. Republic of Macedonia
   22. Norway
   23. Poland
   24. Portugal
   25. Romania
   26. Serbia
   27. Slovenia
   28. Spain
   29. Sweden
   30. Turkey
   31. Ukraine
   32. United Kingdom
6. Latin America
   1. Argentina
   2. Brazil
   3. Chile
   4. Colombia
   5. Costa Rica
   6. Mexico
   7. Panama
   8. Peru
   9. Venezuela
7. Middle East
8. Africa
   1. South Africa
   2. Other Africa
9. New Zealand
10. USA
    1. Alabama
    2. Arizona
    3. Arkansas
    4. California
    5. Colorado
    6. Florida
    7. Georgia
    8. Hawaii
    9. Idaho
    10. Illinois
    11. Indiana
    12. Iowa
    13. Kansas
    14. Kentucky
    15. Maryland
    16. Massachusetts
    17. Michigan
    18. Minnesota
    19. Missouri
    20. Nebraska
    21. New Hampshire
    22. New Jersey
    23. New Mexico
    24. New York
    25. North Carolina
    26. Ohio
    27. Oklahoma
    28. Oregon
    29. Pennsylvania
    30. South Carolina
    31. Tennessee
    32. Texas
    33. Utah
    34. Vermont
    35. Virginia
    36. Washington, DC
    37. Washington
    38. Wisconsin

## Asia

- IRC: http://webchat.freenode.net/?channels=python-apac

### Bangladesh

- Python Bangladesh is the largest Python User Group from Bangladesh: http://pybd.org

### Cambodia(សីល >>> សមាធិ >>> បញ្ញា)

- pythonkhmer[at]google[dot]com- Mailing lists for PyKhmer(cambodian user group)

### China

- Python Chinese User Group - Chinese Python User Group CPUG wiki

- BPUG - Beijing Python User Group (subgroup of CPUG)

- ZEUUX - ZEUUX is a free software community that has a Python user group.

### Hong Kong

- Hong Kong Python User Group (HKPUG)

### India

- BangPypers (Bangalore Python Users Group) - India (BangPypers wiki)

- KolPy (Kolkata Python User Group) - India

- DehraDun Python User Group(DPUG)

  - -Dehradun Python User Group (DPUG)Facebook Page -Follow Dehradun Python On Twitter

    - -Dehradun Python User Group(DPUG) Mailing List

      - -Dehradun Python User Group's Blog

- BangPypers Meetup Group

- Python Developers Baroda - Python Dev Baroda Facebook page -Google group

- GTU Python User Group, Ahmedabad - '''Meetup Group'''

- PyGuj (Python User Group - Gujarat)

  - Google Group PyGuj Facebook Page @Pyguj on Twitter

- ChennaiPy (Chennai Python User Group) - India

- KPUG - Kerala Python User Group

- MumPy - Mumbai Python User Group

- PyDelhi - Python Delhi User Group (Website)

- Pune Python User Group

- IITD Lug - IIT Delhi Lug has active Python users

- Hyderabad Python Meetup Group

- http://www.meetup.com/PyladiesBangalore - Pyladies Bangalore, India

### Indonesia

- Python User Group in Indonesia

- Blog

- GitHub

- IRC

- Mailing List

- Members - Python Indonesia Community Maps

- Meetup.com

- Planet

- Twitter

### Iran

- Mailing List - Python Users Group in Mashhad

- Tehran Python User Group (TehPUG)

  - Web Site

  - Mailing List

  - Facebook

  - Twitter

  - IRC Channel

  - Trello Board

  - Github

  - YouTube

### Japan

- PyJUG - Python Japan User Group. Japanese mailing list: python-ml-jp

### Pakistan

- Python Pakistan- National - Pakistani Pythonistas User Group

### Korea

- PyKUG - Python Users Group in Korea

### Malaysia

- Malaysia PUG - Malaysia Python User Group

### Nepal

- DN: Python Users Group Nepal

  - Facebook Group

  - DN: Python Users Group Nepal Meetups

  - DN: Python Users Group Nepal Google Group

### Singapore

- Website:

  - PUGS - Python User Group Singapore

  - http://pythonsingapore.com

  - http://python.sg

- Facebook Group:

  - https://www.facebook.com/groups/pythonsg

  - https://www.facebook.com/groups/337504009663063

- Google Group:

  - https://groups.google.com/group/pythonsg

  - https://groups.google.com/group/ladypy (local pyladies)

- IRC:

  - http://webchat.freenode.net/?channels=python-sg

### Sri Lanka

- Sri Lanka Python User Group (LK-PUG) LK-PUG Facebook fan page

### Taiwan

- PyTUG Wiki - Taiwan Python User Group

- PyTUG Groups - Taiwan Python User Group

- PyHUG Meetups - Hsinchu Python User Group

- Taipei.py Meetups - Taipei Python User Group

- Tainan.py Meetups - Tainan Python User Group

### Philippines

- Google Groups page

- Facebook Groups page

- IRC: #pythonph

### Thailand/ประเทศไทย

- ThaiPy - Bangkong Python Meetup Group

## Oceania

- Google Group: http://groups.google.com/group/python-apac

- IRC: http://webchat.freenode.net/?channels=python-apac

### Australia

- Mailing list for Australian Python users.

- Brisbane - A monthly meeting of food, drink and Python.

- MelbournePUG - meets for talks, chats, food and drink on the first Monday of each month in Melbourne.

- Sydney Python Users Group - A group of Python users who meet in Sydney for discussions and drinks every couple of months. See also our maillist.

- CanberraPUG - revitalised Canberra User Group, first Thursday of every month at Peoplebank offices, Canberra City: https://plus.google.com/u/0/communities/103339628935802168974.

- North Queensland Python Users Group (PyNQ) - Pythonistas and friends getting together in Townsville (at present - venue/times TBD). Visit the site to register interest.

- Perth Django Users Group - Django and Python enthusiasts alike.

### New Zealand

- New Zealand Python User Group (NZPUG)

## Canada

- TorontoDjangoPython - Toronto Python/Django User group.

- MontrealPython - Montreal's Python community.

- OPAG - Ottawa Python Authors Group. A group devoted to learning, using and providing resources for Python. OPAG also serves as a general gathering place for Python programmers from the Ottawa region and beyond.

- PyGTA - the Toronto Python/Zope User Group meets regularly to explore the expanding world of Python and Zope.

- KWPUG - the Kitchener/Waterloo Python User Group - just starting July 17, 2006.

- WinniPUG - Winnipeg Python Users Group - active since December 2005.

- VanPyZ - The Vancouver Python and Zope User Group discusses Python and various uses of the language.

- WatPy - The Waterloo Region Python User Group. Started in February 2012.

## Caribbean

- JamaicanPy: JamaicanPy, Jamaican Python Community Mailing List, Programming Opportunities etc....

- prPIG: Puerto Rico Python Interest Group. Started in January 2013.

- TTPUG - Trinidad and Tobago Python Users Group

- PyDo - Python Dominicana User Group. Started in September 2012.

## Europe

### Austria

- PyUGAT - Python User Group Austria

- pyGraz - Python User Group Graz

- SalzPUG - Salzburg Python User Group

### Belgium

- AFPyro-BE - Python Drinks in Belgium

- pyBug - Python Belgian User Group

- PythonInBelgium - Python in Belgium group on Linkedin

- Charleroi Python User Group - User group at Charleroi

### Croatia

- Croatian Python user group - Zagreb Python User Group

### Czech and Slovak

- http://python.cz - Python community hub

- PyCZ - Czech and Slovak User Group covers both Python and Zope.

### Denmark

- http://pycon.dk - Python Denmark

- http://groups.google.com/group/python-dk Danish Python user group - defunct?

### Finland

- http://python.fi -- Python Finland association

### France

- AFPY Association Python Francophone, French Speaking Python & Zope User Group

### Georgia

- Facebook Group: https://www.facebook.com/groups/PythonGE/

### Germany

#### General Community Resources

- Community Page on the Python Software Verband web site listing all user groups in Germany and Austria

- wiki.python.de German Python Wiki

- Python-Forum.de German Python Forum

- python-de German Python mailing list

- German Python Site containing links to the most important German Python sites and mailing lists (unfortunately rarely updated and often offline).

#### User Groups

- PUB - Python Users Berlin

- pyCologne, the Python User Group Köln - Cologne, Germany

- Hamburg Python User Group - Hamburg, Germany

- Leipzig Python User Group - Leipzig, Germany

- User Group München - the Python User Group in Munich

- Python Meeting Düsseldorf (PyDDF) - Düsseldorf, Germany; PyDDF Videos on YouTube.

- Python User Group Freiburg - Freiburg, Germany

- Python User Group Rhein-Main Python Community im Rhein-Main Gebiet

### Greece

- Python.org.gr The Greek Python User Group.

### Hungary

- Hungarian Python Site Contains Hungarian translations of Python tutorials and manual and much more. Good starting point for new Hungarian Python users.

### Iceland

- Reykjavík Python User Group mailing list and notices.

- Reykjavík Python Community on Facebook.

### Ireland

- Python Ireland - Irish Python Users Group

### Italy

- Python.it - Italian Python Website

- Pydinner - Python dinners (and beers!)

- PyPg - Python Local User Group Perugia

### Kosovo

- Prishtina Python Group

### Latvia

- Python User Group Latvia

### Malta

- PyMalta (under construction) - a Python group for the Maltese islands; also see the community trello group.

### Moldova

- Facebook Group: https://www.facebook.com/groups/pymoldova/

### Montenegro

- Python Montenegro Python Community of Montenegro (Crna Gora). You can connect with us on social media: Facebook and LinkedIn.

### The Netherlands

- PUN - Python Users Nederland.

- PyGrunn - Python Usergroup Groningen.

- APMG - Amsterdam Python Meetup Group.

### Republic of Macedonia

- http://groups.google.com/group/python-mk Python users group in Macedonia, meetings in the KIKA hackerspace

### Norway

- GrimPypers - Python User Group - Grimstad, Norway

- Norwegian Python Interest Group - Python User Group - Norway

- itlosjen - Python Users - Kristiansand

### Poland

- pl.python.org - Polish Python Community (Polish Python Coders Group)

- Pykonik - Cracow's Python Users Group

- PyWaw - Python community in Warsaw

- PySilesia - Python community in Silesia area

### Portugal

- Python Portugal - Portuguese Python User Group

- Python Porto - Oporto city Python User Group

### Romania

- RoPython - Romanian Python community (originally from Iași)

  - RoPython-Timisoara - Timișoara's branch

  - RoPython-Cluj - Cluj-Napoca's branch

  - RoPython-Iasi - Iași's branch

### Serbia

- Python Interests Group of Serbia Serbian speaking Python user group.

### Slovenia

- Slovenski Ortodoksni Uporabniki Pythona ;)

### Spain

- Asociación Python España Python Spain Association. Organisers of PyConES

- Python en català Catalan Python user group.

- The Barcelona Python Meetup Group Barcelona Python user group.

- Python-Madrid es un grupo de usuarios de Python con reuniones mensuales. Twitter - Mailing List - Meetup

- Zaragoza Python user group Zaragoza Python User group

- Mallorca Python Meetup Mallorca Python user group.

### Sweden

- GothPy Gothenburg Python User Group.

- PySthlm Stockholm Python User Group.

- SkanePy Skåne Python User Group

### Turkey

- Pyİstanbul İstanbul Python User Group.

### Ukraine

- Plone Ukraine - Plone Users Group - Ukraine

### United Kingdom

- London Python

- Python West Midlands - UK

- Python North West

- Cambridge and East Anglia

- Yorkshire

- Python Sheffield

- Python North East - Python North East is a Python user group for the North East of UK covering areas from Northumberland, Tyne & Wear, Teesside to Yorkshire

- Brighton and Hove Python User Group

- Python Edinburgh

- Oxford Python

- Python Liverpool

- London Financial Python User Group

## Latin America

### Argentina

- PyAr - Python Argentina: Community portal, mailing list, job list, meetings, sprints, etc.

### Brazil

- Python Brasil - National - Python Brazilian Community.

- Conference PythonBrasil - National Conference - Python Brazilian Community.

  - Regional (by State)

    - PyTchê - Rio Grande do Sul

    - Grupy-BA - Bahia

    - GrUPy-DF - Brasília

    - PUG-PB - Paraíba -Github

    - GrUPy-PR - Paraná

    - PUG-PE - Pernambuco

    - PythOnRio - Rio de Janeiro - Official Site, Twitter and Photos

    - PUG-SC - Santa Catarina

    - Grupy-SP - São Paulo - Photos and Videos

    - PUG-PI - Piauí - Github

  - Local (by city)

    - Grupy-RP - Ribeirão Preto

### Chile

- Python Chile Python Community in Chile, Mailing list, Job offers, Twitter

### Colombia

- - Python Colombia Grupo de usuarios y desarrolladores de aplicaciones en Python.

### Costa Rica

- Python Costa Rica Grupo de usuarios de Python en Costa Rica

### Mexico

- - Python México Python Community in México.

- - PythonCabal Python User Group in Guadalajara, meets the fourth Monday of every month at the HP cafeteria.

- - Python Monterrey Python User Group in Monterrey.

### Panama

- - Pynama: Python User Community in Panama.

### Peru

- - Python Perú Python User Community in Perú.

- - Python Perú: Community Portal of Python in Perú.

- Python Peru. Peruvian Python User Comunity. Send e-mail to python-pe-subscribe@aqpglug.org.pe

### Venezuela

- - Python Venezuela (PyVE)

## Middle East

- Python MENA

- Iranian Community - Python Users' Community in Iran

- Python Israel - Python users community in Israel

## Africa

### South Africa

- Cape Town Python Users Group - Cape Town

- Durban Hyperion Python Team - Durban

- Zimbabwe Python User Group -Zimbabwe

### Other Africa

- Python Egypt - Egypt and Arab World

- Python Maroc - Maroc et Maghreb

- Python Tunisia - Tunisia

- Python Algeria - Algeria

- Python Algeria 2 - Algeria

- Nairobi Python User Group - Nairobi, Kenya.

- Angola Python User Group - Angola (Luanda)

- FasoPy - Groupe des Utilisateurs de Python au Burkina Faso(Ouagadougou)

## New Zealand

- New Zealand Python User Group

- Python, Zope and Plone Users Group of New Zealand

## USA

### Alabama

- PyHam - Birmingham Area Python Users Group.

- hsv.py - Huntsville and North Alabama Area Python Users Group.

### Arizona

- DesertPy - The Phoenix area Python User Group. - DesertPy Website - DesertPy Meetup

- PhoenixGeoPythonGroup] - New Phoenix Geo/Python User Group - [http://phxgeo.org]

- TuPLE - Tucson Python Language Enthusiasts. Mailing list

### Arkansas

- PyAR^2 - Python Artists of Arkansas

### California

- BayPiggies - San Francisco Bay Area Python Interest Group.

- SYPUG - SoCal Youth Python User Group.

- SoCal Piggies - Southern California Python Interest Group.

- San Diego Python Users Group - San Diego Python Users' Group

- OCPUG - Orange County Python User Group

- PyLadies - Women in Los Angeles

- IEPUG - Inland Empire Python User Group

### Colorado

- FrontRangePythoneers - We meet every third Wednesday, 6-8 PM, in Boulder, Colorado.

- Fort Collins, Colorado Pythoneers. Meeting the first Thursday of every month in Fort Collins, Colorado.

- Colorado Springs, PySprings - Meets twice a month, alternating tuesdays. We do both project and presentation nights.

### Florida

- Tampa Bay PUG - Meeting every 2nd Wednesday, in Clearwater, FL

### Georgia

- PyAtl Atlanta, Georgia Python User Group

### Hawaii

- HI PUG Honolulu, Hawaii Python User Group

- PyHawaii: Bringing Python to Honolulu, Hawaii and the Pacific

  - Join PyHawaii'smeetup.com group

  - Check us out on Facebook, Github, and Twitter.

### Idaho

- BAPUG Boise Area Python User Group

### Illinois

- ChiPy - The Chicago Python Users Group

- Chicago Pythonistas

- Py-CU - The Champaign-Urbana Python Users Group

  - Join our mailing list

  - Check us out on Facebook, Github, and Twitter.

- (Defunct) IlliPy - The Champaign-Urbana Python Users Group

  - Visit the illipy-announce Google Group site to subscribe for user group announcements.

  - Visit the illipy-discuss Google Group site to subscribe for user group discussions.

### Indiana

- Indianapolis, IN - The IndyPy User Group

- DerbyPy - Louisville / Southern Indiana User Group

### Iowa

- Iowa Python Users Group

### Kansas

- CaneyPUGgies - Caney Python Users Group - Meets every Tuesday to learn web development using TurboGears. Remote attendees welcome!

- PythonKC (pyKC) - Python developers, enthusiast and hackers of the Kansas City Metro Area and surroundings.

### Kentucky

- DerbyPy - Louisville / Southern Indiana User Group

### Maryland

- BACON-PIG - The Baltimore, Annapolis, Columbia, and Other Northern DC suburbs Python Interest Group.

### Massachusetts

- Boston / Cambridge Python Users Group will be meeting in Boston, MA.

- Springfield/Northampton/Amherst MA Developer's Group Meets 1-2 times per month.

- Southcoast Python User Group will be meeting in Dartmouth, MA.

### Michigan

- Michipug - Michigan (Detroit / Ann Arbor) Python group is just starting up

- GRPUG - A Python Users Group in Grand Rapids, Michigan

### Minnesota

- PyMNtos - Minnesota Python Users Group, meets the 2nd Thursday of the month.

- PY FM - PY FM, Fargo-Moorhead Python Users Group, meets on the last Wednesdays every month.

- PyRochesterMN - Rochester, MN. Meets on the fourth Thurdsay every month.

### Missouri

- pyCOMO - Python User Group for CoMO (Columbia, MO)

- Southern Missouri Python Interest Group

- PythonKC (pyKC) - Python developers, enthusiast and hackers of the Kansas City Metro Area and surroundings.

- PySGF - A Python User Community in Springfield, MO

- STL Python - St Louis Python meetup

### Nebraska

- Omaha Python Users Group -- Meetings on the 2nd Thursday of the month. Check the wiki more details.

### New Hampshire

- Python SIG of the Greater New Hampshire Linux User Group meets the 4th Thursday in Manchester, NH. Mailing list courtesy of the Dartmouth-Lake Sunapee Linux User Group.

### New Jersey

- PIGIP NJ: Python Interest Group In Princeton, NJ.

### New Mexico

- AbqPython Python Users Group in Albuquerque, NM.

### New York

- NYC Python: Python Users Group In New York City, NY

- NYLUG Python Workshop Python study/discussion/project group in New York City. Mailing list Meets every other week.

- RocPy: Rochester, New York's only Python Users Group

### North Carolina

- TriPython: The Triangle Python Userd Group (formerly TriZPUG) in the Raleigh-Durham-Chapel Hill (Research Triangle) area of North Carolina, USA.

- CharPy: The Charlotte Python Group. Seeking members and ideas for the location of our first meetup. Join and discuss!

- PYPTUG: The PYthon Piedmont Triad User Group in the Winston Salem-Greensboro-High Point (Piedmont Triad) area of North Carolina, USA.

### Ohio

- Clepy: The Cleveland Area Python Interest Group. New members welcome!

- Central Ohio Python User Group

- CincyPy

### Oklahoma

- OPy: Oklahoma's first Python User Group. Located in Norman, OK.

- Tulsa Web Devs - Website, Facebook Group

### Oregon

- Portland - Portland Python Users Group

### Pennsylvania

- The Philadelphia Python Users Group (PhillyPUG).

- Altoona Python. Altoona Python Users Group

- Pgh Py Pittsburgh Python User Group

### South Carolina

- Greenville Python Meetup

### Tennessee

- Chattanooga, TN user group

- Knoxville, TN user group

- MEMpy Memphis, TN Python User Group

- PyNash Nashville, TN Python User Group

### Texas

- Texas-wide organization

- Dallas-Ft. Worth (Texas) Pythoneers (w/wiki and local mailing lists)

- APUG - Austin (Texas) Python User Group.

- Houston Python Meetup site

### Utah

- Utah Python Meta Group — Provides resources for all interested Utah Pythonistas

  - Salt Lake City

  - Draper, Sandy

  - Logan/Northern Utah

  - Provo

### Vermont

- Burlington Python - Python User Group in Burlington, VT. We've got pizza!

  - Meetup

### Virginia

- Fredericksburg ZPUG: Meets at the Zope Corporation building in Fredericksburg, Virginia.

- Charlottesville - Charlottesville Python User Group.

- 757 Python User Group - Hampton Roads and northeastern NC.

- NOVA-Python - Northern Virginia Python User Group, meets at the ScienceLogic office in Reston, VA.

- PyRVA - Richmond area Python User Group starting up in Fall 2015/Winter 2016. Visit the Meetup page or PyRVA.org for more information.

### Washington, DC

- ZPUGDC: Zope/Python Users Group - Washington, DC.

- django-district: a group for Django users in the Washington, D.C. area

### Washington

- Seattle Python Interest Group

- Puget Sound Programming Python User Group (PuPPy)

- Python Spokane

- Whatcom County Python Users

### Wisconsin

- Madison Python Users' Group

- FoxPUG - Fox Valley (Oshkosh/Appleton) Python Users Group

CategoryUsergroups CategoryUsergroups CategoryUsergroups CategoryUsergroups CategoryUsergroups CategoryUsergroups

1. Python User Groups are sometimes called PIGgies, for Python Interest Group meetings. The term PIGgies was coined by the Bay Area PIGgies group. (1)

LocalUserGroups (last edited 2016-02-03 02:28:20 by RobertRoskam)

Unable to edit the page? See the FrontPage for instructions.